@@ -341,12 +341,12 @@ static int parse_mjd_from_string(PyObject *so, double *mjdp)
 	  goto fail;
 
      if (len >= 1) {
+	  int i;
           char *s = PyString_AsString(PyList_GetItem(pieces, 0));
           if (!s) goto fail;
 
 	  /* Make sure all characters are in set '-/.0123456789' */
 
-	  int i;
 	  for (i=0; s[i]; i++) {
 	       if (s[i] != '-' && s[i] != '/' && s[i] != '.'
 		   && (s[i] < '0' || s[i] > '9')) {
@@ -954,7 +954,7 @@ static PyMethodDef Observer_methods[] = {
 static PyGetSetDef Observer_getset[] = {
      {"date", getd_mjd, setd_mjd, "Date", VOFF(n_mjd)},
      {"lat", getd_rd, setd_rd, "Latitude (degrees north)", VOFF(n_lat)},
-     {"long", getd_rd, setd_rd, "Longitude (degrees east)", VOFF(n_lng)},
+     {"lon", getd_rd, setd_rd, "Longitude (degrees east)", VOFF(n_lng)},
      {"elevation", get_elev, set_elev,
       "Elevation above sea level (meters)", NULL},
      {"horizon", getd_rd, setd_rd,
@@ -962,6 +962,10 @@ static PyGetSetDef Observer_getset[] = {
       " should be considered at the moment of rising or setting (degrees)",
       VOFF(n_dip)},
      {"epoch", getd_mjd, setd_mjd, "Precession epoch", VOFF(n_epoch)},
+
+     /* For compatibility with older scripts: */
+     {"long", getd_rd, setd_rd, "Longitude (degrees east)", VOFF(n_lng)},
+
      {NULL}
 };
 
@@ -1065,13 +1069,14 @@ static int Planet_setup(Planet *planet, int builtin_index,
 
 static int Planet_init(PyObject *self, PyObject *args, PyObject *kw)
 {
+     int builtin_index;
      PyObject *o = PyObject_GetAttrString(self, "__planet__");
      if (!o) {
           PyErr_SetString(PyExc_TypeError, "internal error: cannot"
                            " init Planet without a __planet__ code");
           return -1;
      }
-     int builtin_index = PyInt_AsLong(o);
+     builtin_index = PyInt_AsLong(o);
      Py_DECREF(o);
      if ((builtin_index == -1) && PyErr_Occurred()) {
           PyErr_SetString(PyExc_TypeError, "internal error: __planet__"
@@ -1688,13 +1693,18 @@ static PyGetSetDef Body_getset[] = {
 };
 
 static PyGetSetDef Planet_getset[] = {
-     {"hlong", Get_hlong, 0, "heliocentric longitude"
+     {"hlon", Get_hlong, 0, "heliocentric longitude"
       " (radians that print as degrees)"},
      {"hlat", Get_hlat, 0, "heliocentric latitude"
       " (radians that print as degrees)"},
      {"sun_distance", Get_sun_distance, 0, "distance from sun (AU)"},
      {"earth_distance", Get_earth_distance, 0, "distance from earth (AU)"},
      {"phase", Get_phase, 0, "phase (percent illuminated)"},
+
+     /* For compatibility with older scripts: */
+     {"hlong", Get_hlong, 0, "heliocentric longitude"
+      " (radians that print as degrees)"},
+
      {NULL}
 };
 
@@ -2454,25 +2464,33 @@ static int separation_arg(PyObject *arg, double *lngi, double *lati)
 	  *lati = b->obj.s_dec;
 	  return 0;
      } else if (PySequence_Check(arg) && PySequence_Size(arg) == 2) {
-	  PyObject *lngo, *lato, *lngf, *latf;
+          int rval = -1;
+	  PyObject *lngo = 0, *lato = 0, *lngf = 0, *latf = 0;
 	  lngo = PySequence_GetItem(arg, 0);
-	  if (!lngo) return -1;
+	  if (!lngo) goto fail;
 	  lato = PySequence_GetItem(arg, 1);
-	  if (!lato) return -1;
-	  if (!PyNumber_Check(lngo) || !PyNumber_Check(lato)) goto fail;
+	  if (!lato) goto fail;
+	  if (!PyNumber_Check(lngo) || !PyNumber_Check(lato)) {
+               PyErr_SetString(PyExc_TypeError, err_message);
+               goto fail;
+          }
 	  lngf = PyNumber_Float(lngo);
-	  if (!lngf) return -1;
+	  if (!lngf) goto fail;
 	  latf = PyNumber_Float(lato);
-	  if (!latf) return -1;
+	  if (!latf) goto fail;
 	  *lngi = PyFloat_AsDouble(lngf);
 	  *lati = PyFloat_AsDouble(latf);
-	  Py_DECREF(lngf);
-	  Py_DECREF(latf);
-	  return 0;
+          rval = 0;
+     fail:
+          Py_XDECREF(lngo);
+          Py_XDECREF(lato);
+	  Py_XDECREF(lngf);
+	  Py_XDECREF(latf);
+          return rval;
+     } else {
+          PyErr_SetString(PyExc_TypeError, err_message);
+          return -1;
      }
-fail:
-     PyErr_SetString(PyExc_TypeError, err_message);
-     return -1;
 }
 
 static PyObject* separation(PyObject *self, PyObject *args)
@@ -2859,7 +2877,7 @@ static PyObject *_next_pass(PyObject *self, PyObject *args)
                riseaz = build_degrees(rs.rs_riseaz);
           }
 
-          if (rs.rs_flags & RS_NOTRANS) {
+          if (rs.rs_flags & (RS_NORISE | RS_NOSET | RS_NOTRANS)) {
                Py_INCREF(Py_None);
                trantm = Py_None;
                Py_INCREF(Py_None);
@@ -2869,7 +2887,7 @@ static PyObject *_next_pass(PyObject *self, PyObject *args)
                tranalt = build_degrees(rs.rs_tranalt);
           }
 
-          if (rs.rs_flags & RS_NOSET) {
+          if (rs.rs_flags & (RS_NORISE | RS_NOSET)) {
                Py_INCREF(Py_None);
                settm = Py_None;
                Py_INCREF(Py_None);
