@@ -5,7 +5,7 @@
 import ephem._libastro as _libastro
 from math import pi
 
-__version__ = '3.7.3.4'
+__version__ = '3.7.4.1'
 
 twopi = pi * 2.
 halfpi = pi / 2.
@@ -182,9 +182,9 @@ def _find_moon_phase(d0, motion, target):
     def f(d):
         _sun.compute(d)
         _moon.compute(d)
-        slong = _libastro.eq_ecl(d, _sun.g_ra, _sun.g_dec)[0]
-        mlong = _libastro.eq_ecl(d, _moon.g_ra, _moon.g_dec)[0]
-        return (mlong - slong - antitarget) % twopi - pi
+        slon = _libastro.eq_ecl(d, _sun.g_ra, _sun.g_dec)[0]
+        mlon = _libastro.eq_ecl(d, _moon.g_ra, _moon.g_dec)[0]
+        return (mlon - slon - antitarget) % twopi - pi
     antitarget = target + pi
     d0 = Date(d0)
     f0 = f(d0)
@@ -241,10 +241,10 @@ class Observer(_libastro.Observer):
         """Return a useful textual representation of this Observer."""
 
         return ('<ephem.Observer date=%r epoch=%r'
-                ' long=%s lat=%s elevation=%sm'
+                ' lon=%s lat=%s elevation=%sm'
                 ' horizon=%s temp=%sC pressure=%smBar>'
                 % (str(self.date), str(self.epoch),
-                   self.long, self.lat, self.elevation,
+                   self.lon, self.lat, self.elevation,
                    self.horizon, self.temp, self.pressure))
 
     def compute_pressure(self):
@@ -319,7 +319,7 @@ class Observer(_libastro.Observer):
                                 ' above the horizon at latitude %s'
                                 % (declination, self.lat))
 
-    def _riset_helper(self, body, start, rising, previous):
+    def _riset_helper(self, body, start, use_center, rising, previous):
         """Internal function for finding risings and settings."""
 
         if isinstance(body, EarthSatellite):
@@ -332,7 +332,7 @@ class Observer(_libastro.Observer):
         def visit_transit():
             d = (previous and self.previous_transit(body)
                  or self.next_transit(body)) # if-then
-            if body.alt + body.radius - self.horizon <= 0:
+            if body.alt + body.radius * use_radius - self.horizon <= 0:
                 raise NeverUpError('%r transits below the horizon at %s'
                                    % (body.name, d))
             return d
@@ -340,11 +340,19 @@ class Observer(_libastro.Observer):
         def visit_antitransit():
             d = (previous and self.previous_antitransit(body)
                  or self.next_antitransit(body)) # if-then
-            if body.alt + body.radius - self.horizon >= 0:
+            if body.alt + body.radius * use_radius - self.horizon >= 0:
                 raise AlwaysUpError('%r is still above the horizon at %s'
                                     % (body.name, d))
             return d
 
+        # Determine whether we should offset the result for the radius
+        # of the object being measured, or instead pretend that rising
+        # and setting happens when its center crosses the horizon.
+        if use_center:
+            use_radius = 0.0
+        else:
+            use_radius = 1.0
+
         # Save self.date so that we can restore it before returning.
         original_date = self.date
 
@@ -361,9 +369,11 @@ class Observer(_libastro.Observer):
         body.compute(self)
         heading_downward = (rising == previous) # "==" is inverted "xor"
         if heading_downward:
-            on_lower_cusp = body.alt + body.radius - self.horizon > tiny
+            on_lower_cusp = (body.alt + body.radius * use_radius
+                             - self.horizon > tiny)
         else:
-            on_lower_cusp = body.alt + body.radius - self.horizon < - tiny
+            on_lower_cusp = (body.alt + body.radius * use_radius
+                             - self.horizon < - tiny)
 
         az = body.az
         on_right_side_of_sky = ((rising == (az < pi)) # inverted "xor"
@@ -385,28 +395,28 @@ class Observer(_libastro.Observer):
         def f(d):
             self.date = d
             body.compute(self)
-            return body.alt + body.radius - self.horizon
+            return body.alt + body.radius * use_radius - self.horizon
 
         d = (d0 + d1) / 2.
         result = Date(newton(f, d, d + minute))
         self.date = original_date
         return result
 
-    def previous_rising(self, body, start=None):
+    def previous_rising(self, body, start=None, use_center=False):
         """Move to the given body's previous rising, returning the date."""
-        return self._riset_helper(body, start, True, True)
+        return self._riset_helper(body, start, use_center, True, True)
 
-    def previous_setting(self, body, start=None):
+    def previous_setting(self, body, start=None, use_center=False):
         """Move to the given body's previous setting, returning the date."""
-        return self._riset_helper(body, start, False, True)
+        return self._riset_helper(body, start, use_center, False, True)
 
-    def next_rising(self, body, start=None):
+    def next_rising(self, body, start=None, use_center=False):
         """Move to the given body's next rising, returning the date."""
-        return self._riset_helper(body, start, True, False)
+        return self._riset_helper(body, start, use_center, True, False)
 
-    def next_setting(self, body, start=None):
+    def next_setting(self, body, start=None, use_center=False):
         """Move to the given body's next setting, returning the date."""
-        return self._riset_helper(body, start, False, False)
+        return self._riset_helper(body, start, use_center, False, False)
 
     def next_pass(self, body):
         """Return the next rising, culmination, and setting of a satellite."""
@@ -482,7 +492,7 @@ class Coordinate(object):
                 ' a coordinate or a Body, not an %r' % (type(a).__name__,)
                 )
 
-        # Two arguments are interpreted as (ra, dec) or (long, lat).
+        # Two arguments are interpreted as (ra, dec) or (lon, lat).
 
         elif len(args) == 2:
             self.set(*args)
@@ -506,32 +516,33 @@ class Equatorial(Coordinate):
     to_radec = get
     from_radec = set
 
-class LongLatCoordinate(Coordinate):
-    def set(self, long, lat):
-        self.long, self.lat = degrees(long), degrees(lat)
+class LonLatCoordinate(Coordinate):
+    def set(self, lon, lat):
+        self.lon, self.lat = degrees(lon), degrees(lat)
 
     def get(self):
-        return self.long, self.lat
+        return self.lon, self.lat
 
-class Ecliptic(LongLatCoordinate):
+class Ecliptic(LonLatCoordinate):
     def to_radec(self):
-        return _libastro.ecl_eq(self.epoch, self.long, self.lat)
+        return _libastro.ecl_eq(self.epoch, self.lon, self.lat)
 
     def from_radec(self, ra, dec):
-        self.long, self.lat = _libastro.eq_ecl(self.epoch, ra, dec)
+        self.lon, self.lat = _libastro.eq_ecl(self.epoch, ra, dec)
 
-class Galactic(LongLatCoordinate):
+class Galactic(LonLatCoordinate):
     def to_radec(self):
-        return _libastro.gal_eq(self.epoch, self.long, self.lat)
+        return _libastro.gal_eq(self.epoch, self.lon, self.lat)
 
     def from_radec(self, ra, dec):
-        self.long, self.lat = _libastro.eq_gal(self.epoch, ra, dec)
+        self.lon, self.lat = _libastro.eq_gal(self.epoch, ra, dec)
 
 # For backwards compatibility, provide lower-case names for our Date
-# and Angle classes.
+# and Angle classes, and also allow "Lon" to be spelled "Long".
 
 date = Date
 angle = Angle
+LongLatCoordinate = LonLatCoordinate
 
 # Catalog boostraps.  Each of these functions imports a catalog
 # module, then replaces itself with the function of the same name that
